nets.nn.modules.rnnbase — nets 0.1 documentation

Table of Contents
Shortcuts

# Source code for nets.nn.modules.rnnbase

    r"""
    Defines the general structure of a Recurrent Network, which can takes the form of a:

    - Recurrent Neural Network,
    - Long Short Term Memory,
    - Gated Recurrent Unit.
    """

    from abc import ABC
    from .module import Module

    # TODO: finalize this abstract class
    class RNNBase(Module, ABC):
        r"""
        Base architecture for Recurrent Networks.
        Every general recurrent layers should extends this class to inherits private attributes and
        helper methods.
        """

        def __init__(self, *args, **kwargs):
            super().__init__()

## Docs

Access comprehensive developer documentation for Nets

View Docs

## Tutorials

Get beginners tutorials and create state-of-the-art models

View Tutorials

## Resources

Check the GitHub page and contribute to the project

View GitHub

To analyze traffic and optimize your experience, we serve cookies on this site. By clicking or navigating, you agree to allow our usage of cookies. As the current maintainers of this site, Facebook’s Cookies Policy applies. Learn more, including about available controls: Cookies Policy.